## $Id: utils.py 14184 2016-09-23 16:38:53Z henrik $
##
## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""General helper functions and utilities for the customer section.
"""

from copy import deepcopy
from waeup.ikoba.customers.utils import (
    CustomersUtils,
    STARTED, CREATED, REQUESTED, APPROVED,
    SUBMITTED, VERIFIED, REJECTED,
    EXPIRED, PROVISIONALLY)
from ikobacustom.uniben.interfaces import MessageFactory as _

class UnibenCustomersUtils(CustomersUtils):
    """A collection of methods subject to customization.
    """

    #: A prefix used when generating new customer ids. Each customer id will
    #: start with this string. The default is 'K'.
    CUSTOMER_ID_PREFIX = u'B'

    DOCMANAGE_CUSTOMER_STATES = (REQUESTED, APPROVED, PROVISIONALLY)

    DOCMANAGE_DOCUMENT_STATES = (CREATED,)

    CONMANAGE_CUSTOMER_STATES = deepcopy(DOCMANAGE_CUSTOMER_STATES)

    CONMANAGE_CONTRACT_STATES = (CREATED,)

    DOCTYPES_DICT = {
        #'UnibenCustomerDocument': _('Uniben Document'),
        'UnibenCustomerPDFDocument': _('Uniben PDF Document'),
        }

    CONTYPES_DICT = {
        'RIAAContract': _('RIAA Contract'),
        }

    SELECTABLE_DOCTYPES_DICT = deepcopy(DOCTYPES_DICT)

    SELECTABLE_CONTYPES_DICT = deepcopy(CONTYPES_DICT)

    EXPORTER_NAMES = (
        'customers',
        'unibencustomerpdfdocuments',
        'riaacontracts')
